@@ -1,6 +1,12 @@
 #' @importFrom R6 R6Class
 NULL
 
+times <- cli::symbol$times
+
+._NULL_ <- logical()
+attr(._NULL_, ".__NULL__") <- logical()
+
+
 var_lab_row <- ".i"
 var_lab_col <- ".j"
 var_lab_mat <- ".m"
