@@ -1,5 +1,7 @@
 test_that("matrixset general loop works", {
 
+  withr::local_options(lifecycle_verbosity = "quiet")
+
   student_results_M <- mutate_matrix(student_results,
                                      failure = Matrix::Matrix(matrix_elm(student_results, 1)),
                                      remedial = Matrix::Matrix(matrix_elm(student_results, 2)))
@@ -10,7 +12,8 @@ test_that("matrixset general loop works", {
   mn <- apply_row(student_results2, mean)
   M <- matrix_elm(student_results2,1)
   mn_ref <- list(failure=apply(M, 1, function(u) list(mean=mean(u)),simplify = FALSE))
-  mn_ref <- c(mn_ref, list(remedial=lapply(mn_ref$failure, function(u) lapply(u, function(v) NULL))))
+  # mn_ref <- c(mn_ref, list(remedial=lapply(mn_ref$failure, function(u) lapply(u, function(v) NULL))))
+  mn_ref <- c(mn_ref, list(remedial=NULL))
 
   expect_equal(mn, mn_ref)
 
@@ -65,7 +68,7 @@ test_that("matrixset general loop works", {
 
 
 
-  ct <- apply_row(student_results_M, mn=mean, md=median(.i))
+  ct <- apply_row(student_results_M, mn=mean, md=~median(.i))
   ct_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
                      M <- matrix_elm(student_results_M,m)
@@ -79,7 +82,7 @@ test_that("matrixset general loop works", {
 
 
 
-  ct <- apply_column(student_results_M, mn=mean, md=median(.j))
+  ct <- apply_column(student_results_M, mn=mean, md=~median(.j))
   ct_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
                      M <- matrix_elm(student_results_M,m)
@@ -93,7 +96,7 @@ test_that("matrixset general loop works", {
 
 
 
-  ct <- apply_row(student_results_M, mn=mean, reg = lm(.i ~ national_average + program))
+  ct <- apply_row(student_results_M, mn=mean, reg = ~lm(.i ~ national_average + program))
   ct_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
                      M <- matrix_elm(student_results_M,m)
@@ -115,7 +118,7 @@ test_that("matrixset general loop works", {
 
 
 
-  ct <- apply_column(student_results_M, mn=mean, reg = lm(.j ~ teacher + class))
+  ct <- apply_column(student_results_M, mn=mean, reg = ~lm(.j ~ teacher + class))
   ct_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
                      M <- matrix_elm(student_results_M,m)
@@ -137,7 +140,7 @@ test_that("matrixset general loop works", {
 
 
 
-  ct <- apply_row(student_results_M, mn=mean, reg = lm(.i ~ national_average + program),
+  ct <- apply_row(student_results_M, mn=mean, reg = ~lm(.i ~ national_average + program),
                   .matrix = 2)
   ct_ref <- lapply(2,
                    function(m) {
@@ -161,7 +164,7 @@ test_that("matrixset general loop works", {
 
 
 
-  ct <- apply_column(student_results_M, mn=mean, reg = lm(.j ~ teacher + class),
+  ct <- apply_column(student_results_M, mn=mean, reg = ~lm(.j ~ teacher + class),
                      .matrix = 2)
   ct_ref <- lapply(2,
                    function(m) {
@@ -186,7 +189,7 @@ test_that("matrixset general loop works", {
 
 
   e <- apply_row(student_results_M,
-                 mn = {
+                 mn = ~{
                    ii <- .i
                    mean(ii)
                  })
@@ -205,7 +208,7 @@ test_that("matrixset general loop works", {
 
 
   e <- apply_column(student_results_M,
-                    mn = {
+                    mn = ~{
                       jj <- .j
                       mean(jj)
                     })
@@ -225,7 +228,7 @@ test_that("matrixset general loop works", {
 
 
   e <- apply_row(student_results_M,
-                 s={
+                 s=~{
                    .i + school_average + previous_year_score
                  })
 
@@ -247,7 +250,7 @@ test_that("matrixset general loop works", {
 
 
   e <- apply_column(student_results_M,
-                    s={
+                    s=~{
                       .j + school_average + previous_year_score
                     })
 
@@ -269,21 +272,21 @@ test_that("matrixset general loop works", {
 
 
   # .data
-  rg <- apply_row(student_results_M, reg = unname(coef(lm(.i ~ .data[["national_average"]] + program))))
-  rg_ref <- apply_row(student_results_M, reg = unname(coef(lm(.i ~ national_average + program))))
+  rg <- apply_row(student_results_M, reg = ~unname(coef(lm(.i ~ .data[["national_average"]] + program))))
+  rg_ref <- apply_row(student_results_M, reg = ~unname(coef(lm(.i ~ national_average + program))))
   expect_identical(rg, rg_ref)
 
 
 
-  rg <- apply_column(student_results_M, reg = unname(coef(lm(.j ~ .data[["teacher"]] + class))))
-  rg_ref <- apply_column(student_results_M, reg = unname(coef(lm(.j ~ teacher + class))))
+  rg <- apply_column(student_results_M, reg = ~unname(coef(lm(.j ~ .data[["teacher"]] + class))))
+  rg_ref <- apply_column(student_results_M, reg = ~unname(coef(lm(.j ~ teacher + class))))
   expect_identical(rg, rg_ref)
 
 
 
 
   previous_year_score <- 0.5
-  avr <- apply_row(student_results_M, av=mean(c(.i, previous_year_score)))
+  avr <- apply_row(student_results_M, av=~mean(c(.i, previous_year_score)))
   avr_ref <- lapply(seq(nmatrix(student_results_M)),
                     function(m) {
                       M <- matrix_elm(student_results_M,m)
@@ -298,7 +301,7 @@ test_that("matrixset general loop works", {
 
 
   school_average <- 0.5
-  avr <- apply_column(student_results_M, av=mean(c(.j, school_average)))
+  avr <- apply_column(student_results_M, av=~mean(c(.j, school_average)))
   avr_ref <- lapply(seq(nmatrix(student_results_M)),
                     function(m) {
                       M <- matrix_elm(student_results_M,m)
@@ -313,7 +316,7 @@ test_that("matrixset general loop works", {
 
 
   previous_year_score <- 0.5
-  avr <- apply_row(student_results_M, av=mean(c(.i, .env$previous_year_score)))
+  avr <- apply_row(student_results_M, av=~mean(c(.i, .env$previous_year_score)))
   avr_ref <- lapply(seq(nmatrix(student_results_M)),
                     function(m) {
                       M <- matrix_elm(student_results_M,m)
@@ -328,7 +331,7 @@ test_that("matrixset general loop works", {
 
 
   school_average <- 0.5
-  avr <- apply_column(student_results_M, av=mean(c(.j, .env$school_average)))
+  avr <- apply_column(student_results_M, av=~mean(c(.j, .env$school_average)))
   avr_ref <- lapply(seq(nmatrix(student_results_M)),
                     function(m) {
                       M <- matrix_elm(student_results_M,m)
@@ -344,7 +347,7 @@ test_that("matrixset general loop works", {
 
 
   # 1-row/1 column
-  avr <- apply_column(student_results_M[,1,], avr = mean(.j))
+  avr <- apply_column(student_results_M[,1,], avr = ~mean(.j))
   avr_ref <- lapply(seq(nmatrix(student_results_M)),
                     function(m) {
                       M <- matrix_elm(student_results_M,m)
@@ -357,7 +360,7 @@ test_that("matrixset general loop works", {
 
 
 
-  avr <- apply_column(student_results_M[1,1,], avr = mean(.j))
+  avr <- apply_column(student_results_M[1,1,], avr = ~mean(.j))
   avr_ref <- lapply(seq(nmatrix(student_results_M)),
                     function(m) {
                       M <- matrix_elm(student_results_M,m)
@@ -370,7 +373,7 @@ test_that("matrixset general loop works", {
 
 
 
-  avr <- apply_row(student_results_M[1,,], avr = mean(.i))
+  avr <- apply_row(student_results_M[1,,], avr = ~mean(.i))
   avr_ref <- lapply(seq(nmatrix(student_results_M)),
                     function(m) {
                       M <- matrix_elm(student_results_M,m)
@@ -382,7 +385,7 @@ test_that("matrixset general loop works", {
 
 
 
-  avr <- apply_row(student_results_M[1,1,], avr = mean(.i))
+  avr <- apply_row(student_results_M[1,1,], avr = ~mean(.i))
   avr_ref <- lapply(seq(nmatrix(student_results_M)),
                     function(m) {
                       M <- matrix_elm(student_results_M,m)
@@ -478,6 +481,8 @@ test_that("matrixset general loop works", {
 
 test_that("matrixset 'long' loop works", {
 
+  withr::local_options(lifecycle_verbosity = "quiet")
+
   student_results_M <- mutate_matrix(student_results,
                                      failure = Matrix::Matrix(matrix_elm(student_results, 1)),
                                      remedial = Matrix::Matrix(matrix_elm(student_results, 2)))
@@ -489,7 +494,8 @@ test_that("matrixset 'long' loop works", {
   M <- matrix_elm(student_results2,1)
   ct_ref <- list(failure=t(apply(M, 1, function(u) c(mn=mean(u), md=median(u)),simplify = TRUE)))
   ct_ref$failure <- tibble::as_tibble(ct_ref$failure, rownames = ".rowname")
-  ct_ref$remedial <- tibble::tibble(.rowname = character(), mn = logical(), md = logical())
+  # ct_ref$remedial <- tibble::tibble(.rowname = character(), mn = logical(), md = logical())
+  ct_ref["remedial"] <- list(NULL)
   expect_identical(ct, ct_ref)
 
 
@@ -500,7 +506,8 @@ test_that("matrixset 'long' loop works", {
   M <- matrix_elm(student_results2,1)
   ct_ref <- list(failure=t(apply(M, 2, function(u) c(mn=mean(u), md=median(u)),simplify = TRUE)))
   ct_ref$failure <- tibble::as_tibble(ct_ref$failure, rownames = ".colname")
-  ct_ref$remedial <- tibble::tibble(.colname = character(), mn = logical(), md = logical())
+  # ct_ref$remedial <- tibble::tibble(.colname = character(), mn = logical(), md = logical())
+  ct_ref["remedial"] <- list(NULL)
   expect_identical(ct, ct_ref)
 
 
@@ -526,7 +533,7 @@ test_that("matrixset 'long' loop works", {
 
 
   # showcase > 1 length answer
-  summ <- apply_row_dfl(student_results_M, mn=c(mean(.i), median(.i)), rg=range(.i))
+  summ <- apply_row_dfl(student_results_M, mn=~c(mean(.i), median(.i)), rg=~range(.i))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   summ_ref <- lapply(M,
                      function(m) {
@@ -549,7 +556,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  summ <- apply_column_dfl(student_results_M, mn=c(mean(.j), median(.j)), rg=range(.j))
+  summ <- apply_column_dfl(student_results_M, mn=~c(mean(.j), median(.j)), rg=~range(.j))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   summ_ref <- lapply(M,
                      function(m) {
@@ -572,7 +579,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  summ <- apply_row_dfl(student_results_M, mn=c(mn=mean(.i), md=median(.i)), rg=range(.i))
+  summ <- apply_row_dfl(student_results_M, mn=~c(mn=mean(.i), md=median(.i)), rg=~range(.i))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   summ_ref <- lapply(M,
                      function(m) {
@@ -596,7 +603,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  summ <- apply_column_dfl(student_results_M, mn=c(mn=mean(.j), md=median(.j)), rg=range(.j))
+  summ <- apply_column_dfl(student_results_M, mn=~c(mn=mean(.j), md=median(.j)), rg=~range(.j))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   summ_ref <- lapply(M,
                      function(m) {
@@ -623,7 +630,7 @@ test_that("matrixset 'long' loop works", {
   # error
   expect_error(apply_row_dfl(student_results_M,
                              mn=mean,
-                             reg = lm(.i ~ national_average + program)),
+                             reg = ~lm(.i ~ national_average + program)),
                "vectors must be of the same length")
 
 
@@ -631,14 +638,14 @@ test_that("matrixset 'long' loop works", {
 
   expect_error(apply_column_dfl(student_results_M,
                                 mn=mean,
-                                reg = lm(.j ~ teacher + previous_year_score)),
+                                reg = ~lm(.j ~ teacher + previous_year_score)),
                "vectors must be of the same length")
 
 
 
 
   # the trick
-  summ <- apply_row_dfl(student_results_M, mn=mean, reg = list(lm(.i ~ national_average + program)))
+  summ <- apply_row_dfl(student_results_M, mn=mean, reg = ~list(lm(.i ~ national_average + program)))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   meta <- column_info(student_results_M)
   summ_ref <- lapply(M,
@@ -655,7 +662,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  summ <- apply_column_dfl(student_results_M, mn=mean, reg = list(lm(.j ~ teacher + previous_year_score)))
+  summ <- apply_column_dfl(student_results_M, mn=mean, reg = ~list(lm(.j ~ teacher + previous_year_score)))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   meta <- row_info(student_results_M)
   summ_ref <- lapply(M,
@@ -672,7 +679,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  summ <- apply_row_dfl(student_results_M, reg = list(lm(.i ~ national_average), lm(.i ~ program)))
+  summ <- apply_row_dfl(student_results_M, reg = ~list(lm(.i ~ national_average), lm(.i ~ program)))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   meta <- column_info(student_results_M)
   summ_ref <- lapply(M,
@@ -698,7 +705,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  summ <- apply_column_dfl(student_results_M, reg = list(lm(.j ~ class), lm(.j ~ teacher)))
+  summ <- apply_column_dfl(student_results_M, reg = ~list(lm(.j ~ class), lm(.j ~ teacher)))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   meta <- row_info(student_results_M)
   summ_ref <- lapply(M,
@@ -726,11 +733,11 @@ test_that("matrixset 'long' loop works", {
 
 
   # this should fail
-  expect_error(apply_row_dfl(student_results_M, mn=mean(.i), rg=range(.i)),
+  expect_error(apply_row_dfl(student_results_M, mn=~mean(.i), rg=~range(.i)),
                "vectors must be of the same length")
 
 
-  expect_error(apply_column_dfl(student_results_M, mn=mean(.j), rg=range(.j)),
+  expect_error(apply_column_dfl(student_results_M, mn=~mean(.j), rg=~range(.j)),
                "vectors must be of the same length")
 
 
@@ -793,7 +800,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  grmn <- apply_row_dfl(column_group_by(student_results_M, program), mn=mean, md=median(.i))
+  grmn <- apply_row_dfl(column_group_by(student_results_M, program), mn=mean, md=~median(.i))
   grs <- column_group_meta(column_group_by(student_results_M, program))
   mn_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
@@ -818,7 +825,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  grmn <- apply_column_dfl(row_group_by(student_results_M, teacher, class), mn=mean, md=median(.j))
+  grmn <- apply_column_dfl(row_group_by(student_results_M, teacher, class), mn=mean, md=~median(.j))
   grs <- row_group_meta(row_group_by(student_results_M, teacher, class))
   grmn_ref <- lapply(seq(nmatrix(student_results_M)), function(m) {
     ans <- grs
@@ -842,7 +849,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  grmn <- apply_row_dfl(column_group_by(student_results_M, program), ct=c(mean(.i), median(.i)))
+  grmn <- apply_row_dfl(column_group_by(student_results_M, program), ct=~c(mean(.i), median(.i)))
   grs <- column_group_meta(column_group_by(student_results_M, program))
   mn_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
@@ -867,7 +874,7 @@ test_that("matrixset 'long' loop works", {
 
 
 
-  grmn <- apply_column_dfl(row_group_by(student_results_M, teacher, class), ct=c(mean(.j), median(.j)))
+  grmn <- apply_column_dfl(row_group_by(student_results_M, teacher, class), ct=~c(mean(.j), median(.j)))
   grs <- row_group_meta(row_group_by(student_results_M, teacher, class))
   grmn_ref <- lapply(seq(nmatrix(student_results_M)), function(m) {
     ans <- grs
@@ -901,6 +908,8 @@ test_that("matrixset 'long' loop works", {
 
 test_that("matrixset 'wide' loop works", {
 
+  withr::local_options(lifecycle_verbosity = "quiet")
+
   student_results_M <- mutate_matrix(student_results,
                                      failure = Matrix::Matrix(matrix_elm(student_results, 1)),
                                      remedial = Matrix::Matrix(matrix_elm(student_results, 2)))
@@ -912,7 +921,8 @@ test_that("matrixset 'wide' loop works", {
   M <- matrix_elm(student_results2,1)
   ct_ref <- list(failure=t(apply(M, 1, function(u) c(mn=mean(u), md=median(u)),simplify = TRUE)))
   ct_ref$failure <- tibble::as_tibble(ct_ref$failure, rownames = ".rowname")
-  ct_ref$remedial <- tibble::tibble(.rowname = character(), mn = logical(), md = logical())
+  # ct_ref$remedial <- tibble::tibble(.rowname = character(), mn = logical(), md = logical())
+  ct_ref["remedial"] <- list(NULL)
   expect_identical(ct, ct_ref)
 
 
@@ -923,7 +933,8 @@ test_that("matrixset 'wide' loop works", {
   M <- matrix_elm(student_results2,1)
   ct_ref <- list(failure=t(apply(M, 2, function(u) c(mn=mean(u), md=median(u)),simplify = TRUE)))
   ct_ref$failure <- tibble::as_tibble(ct_ref$failure, rownames = ".colname")
-  ct_ref$remedial <- tibble::tibble(.colname = character(), mn = logical(), md = logical())
+  # ct_ref$remedial <- tibble::tibble(.colname = character(), mn = logical(), md = logical())
+  ct_ref["remedial"] <- list(NULL)
   expect_identical(ct, ct_ref)
 
 
@@ -949,7 +960,7 @@ test_that("matrixset 'wide' loop works", {
 
 
   # showcase > 1 length answer
-  summ <- apply_row_dfw(student_results_M, mn=c(mean(.i), median(.i)), rg=range(.i))
+  summ <- apply_row_dfw(student_results_M, mn=~c(mean(.i), median(.i)), rg=~range(.i))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   summ_ref <- lapply(M,
                      function(m) {
@@ -961,7 +972,7 @@ test_that("matrixset 'wide' loop works", {
 
 
 
-  summ <- apply_column_dfw(student_results_M, mn=c(mean(.j), median(.j)), rg=range(.j))
+  summ <- apply_column_dfw(student_results_M, mn=~c(mean(.j), median(.j)), rg=~range(.j))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   summ_ref <- lapply(M,
                      function(m) {
@@ -973,7 +984,7 @@ test_that("matrixset 'wide' loop works", {
 
 
 
-  summ <- apply_row_dfw(student_results_M, mn=c(mn=mean(.i), md=median(.i)), rg=range(.i))
+  summ <- apply_row_dfw(student_results_M, mn=~c(mn=mean(.i), md=median(.i)), rg=~range(.i))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   summ_ref <- lapply(M,
                      function(m) {
@@ -985,7 +996,7 @@ test_that("matrixset 'wide' loop works", {
 
 
 
-  summ <- apply_column_dfw(student_results_M, mn=c(mn=mean(.j), md=median(.j)), rg=range(.j))
+  summ <- apply_column_dfw(student_results_M, mn=~c(mn=mean(.j), md=median(.j)), rg=~range(.j))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   summ_ref <- lapply(M,
                      function(m) {
@@ -1000,7 +1011,7 @@ test_that("matrixset 'wide' loop works", {
   # error
   expect_error(apply_row_dfw(student_results_M,
                              mn=mean,
-                             reg = lm(.i ~ national_average + program)),
+                             reg = ~lm(.i ~ national_average + program)),
                "vectors must be of the same length")
 
 
@@ -1008,14 +1019,14 @@ test_that("matrixset 'wide' loop works", {
 
   expect_error(apply_column_dfw(student_results_M,
                                 mn=mean,
-                                reg = lm(.j ~ teacher + previous_year_score)),
+                                reg = ~lm(.j ~ teacher + previous_year_score)),
                "vectors must be of the same length")
 
 
 
 
   # the trick
-  summ <- apply_row_dfw(student_results_M, mn=mean, reg = list(lm(.i ~ national_average + program)))
+  summ <- apply_row_dfw(student_results_M, mn=mean, reg = ~list(lm(.i ~ national_average + program)))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   meta <- column_info(student_results_M)
   summ_ref <- lapply(M,
@@ -1032,7 +1043,7 @@ test_that("matrixset 'wide' loop works", {
 
 
 
-  summ <- apply_column_dfw(student_results_M, mn=mean, reg = list(lm(.j ~ teacher + previous_year_score)))
+  summ <- apply_column_dfw(student_results_M, mn=mean, reg = ~list(lm(.j ~ teacher + previous_year_score)))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   meta <- row_info(student_results_M)
   summ_ref <- lapply(M,
@@ -1048,7 +1059,7 @@ test_that("matrixset 'wide' loop works", {
 
 
 
-  summ <- apply_row_dfw(student_results_M, reg = list(national = lm(.i ~ national_average), program = lm(.i ~ program)))
+  summ <- apply_row_dfw(student_results_M, reg = ~list(national = lm(.i ~ national_average), program = lm(.i ~ program)))
   M <- student_results_M[,,,keep_annotation = FALSE, warn_class_change = FALSE]
   meta <- column_info(student_results_M)
   summ_ref <- lapply(M,
@@ -1068,11 +1079,11 @@ test_that("matrixset 'wide' loop works", {
 
   #
   # # this should fail
-  expect_error(apply_row_dfw(student_results_M, mn=mean(.i), rg=range(.i)),
+  expect_error(apply_row_dfw(student_results_M, mn=~mean(.i), rg=~range(.i)),
                "vectors must be of the same length")
 
 
-  expect_error(apply_column_dfw(student_results_M, mn=mean(.j), rg=range(.j)),
+  expect_error(apply_column_dfw(student_results_M, mn=~mean(.j), rg=~range(.j)),
                "vectors must be of the same length")
 
 
@@ -1132,7 +1143,7 @@ test_that("matrixset 'wide' loop works", {
 
 
 
-  grmn <- apply_row_dfw(column_group_by(student_results_M, program), mn=mean, md=median(.i))
+  grmn <- apply_row_dfw(column_group_by(student_results_M, program), mn=mean, md=~median(.i))
   grs <- column_group_meta(column_group_by(student_results_M, program))
   mn_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
@@ -1157,7 +1168,7 @@ test_that("matrixset 'wide' loop works", {
 
 
 
-  grmn <- apply_column_dfw(row_group_by(student_results_M, teacher, class), mn=mean, md=median(.j))
+  grmn <- apply_column_dfw(row_group_by(student_results_M, teacher, class), mn=mean, md=~median(.j))
   grs <- row_group_meta(row_group_by(student_results_M, teacher, class))
   grmn_ref <- lapply(seq(nmatrix(student_results_M)), function(m) {
     ans <- grs
@@ -1181,7 +1192,7 @@ test_that("matrixset 'wide' loop works", {
 
 
 
-  grmn <- apply_row_dfw(column_group_by(student_results_M, program), ct=c(mean(.i), median(.i)))
+  grmn <- apply_row_dfw(column_group_by(student_results_M, program), ct=~c(mean(.i), median(.i)))
   grs <- column_group_meta(column_group_by(student_results_M, program))
   mn_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
@@ -1206,7 +1217,7 @@ test_that("matrixset 'wide' loop works", {
 
 
 
-  grmn <- apply_column_dfw(row_group_by(student_results_M, teacher, class), ct=c(mean(.j), median(.j)))
+  grmn <- apply_column_dfw(row_group_by(student_results_M, teacher, class), ct=~c(mean(.j), median(.j)))
   grs <- row_group_meta(row_group_by(student_results_M, teacher, class))
   grmn_ref <- lapply(seq(nmatrix(student_results_M)), function(m) {
     ans <- grs
@@ -1232,9 +1243,9 @@ test_that("matrixset 'wide' loop works", {
 
 
   grmn <- apply_row_dfw(column_group_by(student_results_M, program),
-                        ct=c(mn=mean(.i), md=median(.i)),
+                        ct=~c(mn=mean(.i), md=median(.i)),
                         rg=range,
-                        fit=list(lm(.i ~ 1), lm(.i ~ school_average)))
+                        fit=~list(lm(.i ~ 1), lm(.i ~ school_average)))
   grs <- column_group_meta(column_group_by(student_results_M, program))
   mn_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
@@ -1272,9 +1283,9 @@ test_that("matrixset 'wide' loop works", {
 
 
   grmn <- apply_column_dfw(row_group_by(student_results_M, teacher, class),
-                           ct=c(mn=mean(.j), md=median(.j)),
+                           ct=~c(mn=mean(.j), md=median(.j)),
                            rg=range,
-                           fit=list(lm(.j ~ 1), lm(.j ~ previous_year_score)))
+                           fit=~list(lm(.j ~ 1), lm(.j ~ previous_year_score)))
   grs <- row_group_meta(row_group_by(student_results_M, teacher, class))
   mn_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
@@ -1320,6 +1331,8 @@ test_that("matrixset 'wide' loop works", {
 
 test_that("matrixset matrix loop works", {
 
+  withr::local_options(lifecycle_verbosity = "quiet")
+
   student_results_M <- mutate_matrix(student_results,
                                      failure = Matrix::Matrix(matrix_elm(student_results, 1)),
                                      remedial = Matrix::Matrix(matrix_elm(student_results, 2)))
@@ -1328,7 +1341,8 @@ test_that("matrixset matrix loop works", {
   matrix_elm(student_results2,2) <- NULL
   mn <- apply_matrix(student_results2, Matrix::mean)
   M <- matrix_elm(student_results2,1)
-  mn_ref <- list(failure=list(`Matrix::mean`=Matrix::mean(M)), remedial=list(`Matrix::mean`=NULL))
+  # mn_ref <- list(failure=list(`Matrix::mean`=Matrix::mean(M)), remedial=list(`Matrix::mean`=NULL))
+  mn_ref <- list(failure=list(`Matrix::mean`=Matrix::mean(M)), remedial=NULL)
 
   expect_equal(mn, mn_ref)
 
@@ -1359,7 +1373,7 @@ test_that("matrixset matrix loop works", {
 
 
 
-  ct <- apply_matrix(student_results_M, mn=Matrix::mean, md=Matrix::mean(.m))
+  ct <- apply_matrix(student_results_M, mn=Matrix::mean, md=~Matrix::mean(.m))
   ct_ref <- lapply(seq(nmatrix(student_results_M)),
                    function(m) {
                      M <- matrix_elm(student_results_M,m)
@@ -1372,7 +1386,7 @@ test_that("matrixset matrix loop works", {
 
 
   e <- apply_matrix(student_results_M,
-                    mn = {
+                    mn = ~{
                       mm <- .m
                       Matrix::mean(mm)
                     })
@@ -1473,6 +1487,124 @@ test_that("matrixset matrix loop works", {
 
 
 
+
+  grmn <- apply_matrix_dfl(column_group_by(student_results_M, program),
+                           FC = ~Matrix::colMeans(.m),
+                           FC_rob = ~apply(.m, 2, median), .force_name = TRUE)
+  grs <- column_group_meta(column_group_by(student_results_M, program))
+  mn_ref <- lapply(seq(nmatrix(student_results_M)),
+                   function(m) {
+                     ans <- grs
+                     grmn_ref <- lapply(grs$.rows, function(gr) {
+                       M <- matrix_elm(student_results,m)
+                       Mgr <- M[, gr, drop = FALSE]
+                       Matrix::colMeans(Mgr)
+                     })
+                     ans$FC <- grmn_ref
+
+                     grmn_ref <- lapply(grs$.rows, function(gr) {
+                       M <- matrix_elm(student_results,m)
+                       Mgr <- M[, gr, drop = FALSE]
+                       apply(Mgr, 2, median)
+
+                     })
+                     ans$FC_rob <- grmn_ref
+                     ans$.rows <- NULL
+                     ans %>% tidyr::unnest_longer(c(FC, FC_rob)) %>%
+                       dplyr::select(program, FC.name = FC_id, FC,
+                                     FC_rob.name = FC_rob_id, FC_rob) %>%
+                       dplyr::mutate(FC = unname(FC), FC_rob = unname(FC_rob))
+                   })
+  names(mn_ref) <- matrixnames(student_results_M)
+  expect_equal(grmn, mn_ref)
+
+
+
+
+
+
+  grfc <- apply_matrix_dfl(column_group_by(row_group_by(student_results_M, teacher), program),
+                           FC = ~Matrix::colMeans(.m),
+                           FC_rob = ~apply(.m, 2, median), .force_name = TRUE)
+  grs <- column_group_by(row_group_by(student_results_M, teacher), program)
+  grs_row <- row_group_meta(grs)
+  grs_col <- column_group_meta(grs)
+  fc_ref <- lapply(seq(nmatrix(student_results_M)),
+                   function(m) {
+                     ans <- grs_row
+                     M <- matrix_elm(student_results_M,m)
+                     ans$.rows <- NULL
+                     grmn_ref <- lapply(grs_row$.rows, function(grr) {
+                       lapply(grs_col$.rows, function(grc) {
+                         Matrix::colMeans(M[grr, grc, drop = FALSE])
+                       })
+                     })
+                     ans$FC <- grmn_ref
+
+                     grmn_ref <- lapply(grs_row$.rows, function(grr) {
+                       lapply(grs_col$.rows, function(grc) {
+                         apply(M[grr, grc, drop = FALSE], 2, median)
+                       })
+                     })
+                     ans$FC_rob <- grmn_ref
+
+                     ans %>%
+                       tidyr::unnest(c(FC, FC_rob)) %>%
+                       tidyr::unnest_longer(c(FC, FC_rob)) %>%
+                       dplyr::left_join(column_info(student_results) %>%
+                                          dplyr::select(FC_id=.colname, program),
+                                        by = "FC_id") %>%
+                       dplyr::select(teacher, program, FC.name=FC_id, FC,
+                                     FC_rob.name=FC_rob_id, FC_rob) %>%
+                       dplyr::mutate(FC=unname(FC), FC_rob=unname(FC_rob))
+                   })
+  names(fc_ref) <- matrixnames(student_results_M)
+  expect_identical(grfc, fc_ref)
+
+
+
+
+  grmn <- apply_matrix_dfw(column_group_by(student_results_M, program),
+                           FC = ~Matrix::colMeans(.m),
+                           FC_rob = ~apply(.m, 2, median), .force_name = TRUE)
+  mn_ref <- apply_matrix_dfl(column_group_by(student_results_M, program),
+                             FC = ~Matrix::colMeans(.m),
+                             FC_rob = ~apply(.m, 2, median), .force_name = TRUE) %>%
+    lapply(function(m) {
+      m %>% tidyr::pivot_wider(names_from = c(FC.name, FC_rob.name),
+                               values_from = c(FC, FC_rob),
+                               names_glue = "{.value} {FC.name}")
+    })
+  nms <- unlist(unique(lapply(grmn, names)))
+  nms_ref <- unlist(unique(lapply(mn_ref, names)))
+  expect_true(all(nms %in% nms_ref))
+  expect_true(all(nms_ref %in% nms))
+  mn_ref <- purrr::map2(mn_ref, grmn, ~ .x[, names(.y)])
+  expect_identical(grmn, mn_ref)
+
+
+
+
+  ct <- apply_matrix_dfw(column_group_by(row_group_by(student_results_M, teacher), program),
+                         FC = ~Matrix::colMeans(.m),
+                         FC_rob = ~apply(.m, 2, median), .force_name = TRUE)
+  ct_ref <- apply_matrix_dfl(column_group_by(row_group_by(student_results, teacher), program),
+                             FC = ~Matrix::colMeans(.m),
+                             FC_rob = ~apply(.m, 2, median), .force_name = TRUE) %>%
+    lapply(function(m) {
+      m %>% tidyr::pivot_wider(names_from = c(FC.name, FC_rob.name),
+                               values_from = c(FC, FC_rob),
+                               names_glue = "{.value} {FC.name}")
+    })
+  nms <- unlist(unique(lapply(ct, names)))
+  nms_ref <- unlist(unique(lapply(ct_ref, names)))
+  expect_true(all(nms %in% nms_ref))
+  expect_true(all(nms_ref %in% nms))
+  ct_ref <- purrr::map2(ct_ref, ct, ~ .x[, names(.y)])
+  expect_equal(ct, ct_ref)
+
+
+
 })
 
 
